<?php

use QUI\Geo\Utils\GeoPoint;
use QUI\Locations\Controls\LocatorListResult;
use QUI\Utils\Security\Orthos;
use QUI\Locations\Locator\Handler;

/**
 * Get result list for a LocatorList
 *
 * @param float $lat
 * @param float $lng
 * @param float $radius
 * @param int $page
 * @param int $siteId
 * @param bool $listOnly - Only return result list, do not include Pagination
 * @param array $filters
 * @param bool $locationImage - show location image
 * @return string - HTML of LocatorListResult
 */
QUI::$Ajax->registerFunction(
    'package_quiqqer_locations_ajax_frontend_Locator_getLocatorListResult',
    function ($lat, $lng, $radius, $page, $siteId, $listOnly, $filters, $locationImage) {
        if (empty($siteId)) {
            $siteId = 1;
        }

        $Center = false;

        if (!empty($lat) && !empty($lng)) {
            $Center = new GeoPoint((float)$lat, (float)$lng);
        }

        $locatorListAttributes = [
            'Center'        => $Center,
            'radius'        => (float)$radius,
            'page'          => (int)$page,
            'Site'          => QUI::getRewrite()->getProject()->get((int)$siteId),
            'listOnly'      => boolval($listOnly),
            'locationImage' => boolval($locationImage)
        ];

        if (!empty($filters)) {
            $filters                              = Orthos::clearArray(\json_decode($filters, true));
            $locatorListAttributes['locationIds'] = Handler::getAllowedLocationIds($filters);
        }

        $LocatorListResult = new LocatorListResult($locatorListAttributes);

        return $LocatorListResult->getBody();
    },
    ['lat', 'lng', 'radius', 'page', 'siteId', 'listOnly', 'filters', 'locationImage']
);
