<?php

use QUI\Geo\Utils\GeoPoint;
use QUI\Locations\Locator;
use QUI\Utils\Security\Orthos;
use QUI\Locations\Locator\Handler;

/**
 * Get list of all Locations in a certain radius in a format the LocatorMap can be used
 *
 * @param float $lat
 * @param float $lng
 * @param float $radius
 * @param array $filters
 * @param array $project (optional)
 * @param int $siteId (optional)
 * @return array
 */
QUI::$Ajax->registerFunction(
    'package_quiqqer_locations_ajax_frontend_Locator_getMapLocationList',
    function ($lat, $lng, $radius, $filters, $project = null, $siteId = null) {
        $locations    = [];
        $searchParams = [
            'noLimit' => true
        ];

        if (!empty($filters)) {
            $filters                    = Orthos::clearArray(\json_decode($filters, true));
            $searchParams['allowedIds'] = Handler::getAllowedLocationIds($filters);
        }

        $list = Locator::getLocationsInRadius(
            new GeoPoint((float)$lat, (float)$lng),
            $searchParams,
            (float)$radius
        );

        foreach ($list as $entry) {
            $location = $entry['location'];

            if (empty($location['coordinates'])) {
                continue;
            }

            $locations[] = [
                'id'       => $location['id'],
                'lat'      => $location['coordinates']['lat'],
                'lng'      => $location['coordinates']['lng'],
                'map_icon' => Locator::getLocationMapIcon($location['id'])
            ];
        }

        // Sort
        array_multisort(
            array_column($locations, 'lat'),
            \SORT_ASC,
            array_column($locations, 'lng'),
            \SORT_ASC,
            $locations
        );

        $lat = array_column($locations, 'lat');
        $lng = array_column($locations, 'lng');

        sort($lat);
        sort($lng);

        $viewBox    = false;
        $viewCenter = false;

        if (!empty($locations)) {
            $viewBox = [
                'northLat' => $lat[count($lat) - 1],
                'southLat' => $lat[0],
                'eastLng'  => $lng[count($lng) - 1],
                'westLng'  => $lng[0]
            ];
        } else {
            $Site = null;

            if (!empty($project) && !empty($siteId)) {
                try {
                    $Project = QUI::getProjectManager()->decode($project);
                    $Site    = $Project->get((int)$siteId);
                } catch (\Exception $Exception) {
                    QUI\System\Log::writeException($Exception);
                }
            }

            $viewCenter = Handler::getDefaultMapViewCenter($Site);
        }

        return [
            'locations'  => $locations,
            'viewBox'    => $viewBox,
            'viewCenter' => $viewCenter
        ];
    },
    ['lat', 'lng', 'radius', 'filters', 'project', 'siteId']
);
