<?php

use QUI\Locations\Handler\Locations as LocationsHandler;
use QUI\Lock\Locker;

/**
 * Deactivate a Location
 *
 * @param int $locationId - location ID
 * @return bool - success
 */
QUI::$Ajax->registerFunction(
    'package_quiqqer_locations_ajax_locations_deactivate',
    function ($locationId) {
        try {
            $Location = LocationsHandler::getLocation((int)$locationId);
            $Location->deactivate();
        } catch (QUI\Locations\Exception $Exception) {
            QUI::getMessagesHandler()->addError(
                QUI::getLocale()->get(
                    'quiqqer/locations',
                    'message.ajax.locations.deactivate.error',
                    array(
                        'locationId' => $locationId,
                        'error'      => $Exception->getMessage()
                    )
                )
            );

            return false;
        } catch (QUI\Permissions\Exception $Exception) {
            QUI::getMessagesHandler()->addError(
                QUI::getLocale()->get(
                    'quiqqer/locations',
                    'message.ajax.locations.deactivate.error',
                    array(
                        'locationId' => $locationId,
                        'error'      => $Exception->getMessage()
                    )
                )
            );

            return false;
        } catch (\Exception $Exception) {
            QUI\System\Log::addError(
                'AJAX :: package_quiqqer_locations_ajax_locations_deactivate -> ' . $Exception->getMessage()
            );

            QUI::getMessagesHandler()->addError(
                QUI::getLocale()->get(
                    'quiqqer/locations',
                    'message.locations.general.error'
                )
            );

            return false;
        }

        QUI::getMessagesHandler()->addSuccess(
            QUI::getLocale()->get(
                'quiqqer/locations',
                'message.ajax.locations.deactivate.success',
                array(
                    'locationId'   => $locationId,
                    'locationName' => $Location->getLocationAttribute('name')
                )
            )
        );

        return true;
    },
    array('locationId'),
    'Permission::checkAdminUser'
);
