<?php

use QUI\Locations\Handler\Locations as LocationsHandler;

/**
 * Delete one or more location
 *
 * @param array $locationIds - IDs of locations that are to be deleted
 * @return bool - success
 */
QUI::$Ajax->registerFunction(
    'package_quiqqer_locations_ajax_locations_delete',
    function ($locationIds) {
        $locationIds = json_decode($locationIds, true);

        foreach ($locationIds as $locationId) {
            try {
                $Location = LocationsHandler::getLocation((int)$locationId);
                $Location->delete();
            } catch (QUI\Locations\Exception $Exception) {
                QUI::getMessagesHandler()->addError(
                    QUI::getLocale()->get(
                        'quiqqer/locations',
                        'message.ajax.locations.delete.error',
                        array(
                            'locationId' => $locationId,
                            'error'      => $Exception->getMessage()
                        )
                    )
                );

                return false;
            } catch (QUI\Permissions\Exception $Exception) {
                QUI::getMessagesHandler()->addError(
                    QUI::getLocale()->get(
                        'quiqqer/locations',
                        'message.ajax.locations.delete.error',
                        array(
                            'locationId' => $locationId,
                            'error'      => $Exception->getMessage()
                        )
                    )
                );

                return false;
            } catch (\Exception $Exception) {
                QUI\System\Log::addError(
                    'AJAX :: package_quiqqer_locations_ajax_locations_create -> ' . $Exception->getMessage()
                );

                QUI::getMessagesHandler()->addError(
                    QUI::getLocale()->get(
                        'quiqqer/locations',
                        'message.locations.general.error'
                    )
                );

                return false;
            }
        }

        QUI::getMessagesHandler()->addSuccess(
            QUI::getLocale()->get(
                'quiqqer/locations',
                'message.ajax.locations.delete.success'
            )
        );

        return true;
    },
    array('locationIds'),
    'Permission::checkAdminUser'
);
