/**
 * Select recurrence options for a recurring date
 *
 * @module package/quiqqer/locations/bin/controls/attributes/SpecialOpeningHours/RecurrenceSelect
 * @author www.pcsg.de (Patrick Müller)
 */
define('package/quiqqer/locations/bin/controls/attributes/SpecialOpeningHours/RecurrenceSelect', [

    'qui/QUI',
    'qui/controls/Control',

    'Locale',
    'package/quiqqer/locations/bin/controls/utils/DateInput',

    'css!package/quiqqer/locations/bin/controls/attributes/SpecialOpeningHours/RecurrenceSelect.css'

], function (QUI, QUIControl, QUILocale, DateInput) {
    "use strict";

    var lg = 'quiqqer/locations';

    return new Class({

        Extends: QUIControl,
        Type   : 'package/quiqqer/locations/bin/controls/attributes/SpecialOpeningHours/RecurrenceSelect',

        Binds: [
            'getValue',
            'setValue'
        ],

        initialize: function (options) {
            this.parent(options);
            this.$TypeSelect = null;
            this.$loaded     = false;

            this.$DateInputFrom = null;
            this.$DateInputTo   = null;
        },

        /**
         * create the domnode element
         *
         * @return {HTMLDivElement}
         */
        create: function () {
            var self = this;

            this.$Elm = new Element('div', {
                'class': 'quiqqer-locations-recurrenceselect',
                html   : '<div class="quiqqer-locations-recurrenceselect-type"></div>' +
                    '<div class="quiqqer-locations-recurrenceselect-options"></div>'
            });

            this.$TypeSelect = new Element('select', {
                name  : 'type',
                events: {
                    change: function () {
                        self.$setOptions();
                    }
                }
            }).inject(
                this.$Elm.getElement('.quiqqer-locations-recurrenceselect-type')
            );

            // Type options
            new Element('option', {
                html : QUILocale.get(lg, 'controls.attributes.recurrenceselect.type.daterange'),
                value: 'daterange'
            }).inject(this.$TypeSelect);

            new Element('option', {
                html : QUILocale.get(lg, 'controls.attributes.recurrenceselect.type.yearly'),
                value: 'yearly'
            }).inject(this.$TypeSelect);

            new Element('option', {
                html : QUILocale.get(lg, 'controls.attributes.recurrenceselect.type.specialday'),
                value: 'specialday'
            }).inject(this.$TypeSelect);

            this.$TypeSelect.value = 'daterange';

            this.$setOptions();

            return this.$Elm;
        },

        /**
         * Insert option elements according to selected recurrence type
         *
         */
        $setOptions: function () {
            var self       = this;
            var type       = this.$TypeSelect.value;
            var OptionsElm = this.$Elm.getElement(
                '.quiqqer-locations-recurrenceselect-options'
            );

            OptionsElm.set('html', '');

            switch (type) {
                case 'daterange':
                    var FromDateLabel = new Element('label', {
                        html: '<span>' +
                            QUILocale.get(lg, 'controls.attributes.recurrenceselect.daterange.label.from') +
                            '</span>'
                    }).inject(OptionsElm);

                    var ToDateLabel = new Element('label', {
                        html: '<span>' +
                            QUILocale.get(lg, 'controls.attributes.recurrenceselect.daterange.label.to') +
                            '</span>'
                    }).inject(OptionsElm);

                    this.$DateInputFrom = new DateInput({
                        'class': 'quiqqer-locations-recurrenceselect-yearly-daterange-from',
                        events : {
                            onChange: function () {
                                self.fireEvent('change', [self]);
                            }
                        }
                    }).inject(FromDateLabel);

                    this.$DateInputTo = new DateInput({
                        'class': 'quiqqer-locations-recurrenceselect-yearly-daterange-to',
                        events : {
                            onChange: function () {
                                self.fireEvent('change', [self]);
                            }
                        }
                    }).inject(ToDateLabel);
                    break;

                case 'yearly':
                    var FromLabel = new Element('label', {
                        html: '<span>' +
                            QUILocale.get(lg, 'controls.attributes.recurrenceselect.yearly.label.from') +
                            '</span>'
                    }).inject(OptionsElm);

                    var ToLabel = new Element('label', {
                        html: '<span>' +
                            QUILocale.get(lg, 'controls.attributes.recurrenceselect.yearly.label.to') +
                            '</span>'
                    }).inject(OptionsElm);

                    var DayYearlySelectFrom = new Element('select', {
                        'class': 'quiqqer-locations-recurrenceselect-yearly-day' +
                            ' quiqqer-locations-recurrenceselect-yearly-day-from',
                    }).inject(FromLabel);

                    var DayYearlySelectTo = new Element('select', {
                        'class': 'quiqqer-locations-recurrenceselect-yearly-day' +
                            ' quiqqer-locations-recurrenceselect-yearly-day-to',
                    }).inject(ToLabel);

                    var val;

                    for (i = 0; i < 31; i++) {
                        val = (i + 1);

                        if (val < 10) {
                            val = "0" + val;
                        }

                        new Element('option', {
                            html : (i + 1) + '.',
                            value: val
                        }).inject(DayYearlySelectFrom);

                        new Element('option', {
                            html : (i + 1) + '.',
                            value: val
                        }).inject(DayYearlySelectTo);
                    }

                    var MonthYearlySelectFrom = new Element('select', {
                        'class': 'quiqqer-locations-recurrenceselect-yearly-month' +
                            ' quiqqer-locations-recurrenceselect-yearly-month-from',
                    }).inject(FromLabel);

                    var MonthYearlySelectTo = new Element('select', {
                        'class': 'quiqqer-locations-recurrenceselect-yearly-month' +
                            ' quiqqer-locations-recurrenceselect-yearly-month-to',
                    }).inject(ToLabel);

                    for (i = 0; i < 12; i++) {
                        val = (i + 1);

                        if (val < 10) {
                            val = "0" + val;
                        }

                        new Element('option', {
                            html : QUILocale.get(
                                lg,
                                'controls.attributes.recurrenceselect.specialday.month.' + (i + 1)
                            ),
                            value: val
                        }).inject(MonthYearlySelectFrom);

                        new Element('option', {
                            html : QUILocale.get(
                                lg,
                                'controls.attributes.recurrenceselect.specialday.month.' + (i + 1)
                            ),
                            value: val
                        }).inject(MonthYearlySelectTo);
                    }

                    DayYearlySelectFrom.value   = "01";
                    DayYearlySelectTo.value     = "01";
                    MonthYearlySelectFrom.value = "01";
                    MonthYearlySelectTo.value   = "01";
                    break;

                case 'specialday':
                    var i, len;

                    var DayNumberSelect = new Element('select', {
                        'class': 'quiqqer-locations-recurrenceselect-daynum',
                    }).inject(OptionsElm);

                    var dayNumEntries = [
                        'every', 1, 2, 3, 4, 'last'
                    ];

                    for (i = 0, len = dayNumEntries.length; i < len; i++) {
                        new Element('option', {
                            html : QUILocale.get(
                                lg,
                                'controls.attributes.recurrenceselect.specialday.daynum.' + dayNumEntries[i]
                            ),
                            value: dayNumEntries[i]
                        }).inject(DayNumberSelect);
                    }

                    // "in"
                    new Element('span', {
                        'class': 'quiqqer-locations-recurrenceselect-in',
                        html   : QUILocale.get(lg, 'controls.attributes.recurrenceselect.in')
                    }).inject(OptionsElm);

                    var MonthSelect = new Element('select', {
                        'class': 'quiqqer-locations-recurrenceselect-month',
                    }).inject(OptionsElm);

                    var monthEntries = [
                        'month', 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12
                    ];

                    for (i = 0, len = monthEntries.length; i < len; i++) {
                        new Element('option', {
                            html : QUILocale.get(
                                lg,
                                'controls.attributes.recurrenceselect.specialday.month.' + monthEntries[i]
                            ),
                            value: monthEntries[i]
                        }).inject(MonthSelect);
                    }

                    DayNumberSelect.value = 'every';
                    MonthSelect.value     = 'month';

                    break;
            }

            // events
            OptionsElm.getElements('select').addEvents({
                change: function () {
                    self.fireEvent('change', [self]);
                }
            });

            this.fireEvent('change', [self]);
        },

        /**
         * Get current recurrence value
         *
         * @return {Object}
         */
        getValue: function () {
            var type       = this.$TypeSelect.value;
            var OptionsElm = this.$Elm.getElement(
                '.quiqqer-locations-recurrenceselect-options'
            );

            var Data = {
                type: type
            };

            var Options = {};

            switch (type) {
                case 'daterange':
                    Options.from = this.$DateInputFrom.getValue();
                    Options.to   = this.$DateInputTo.getValue();
                    break;

                case 'yearly':
                    var DayYearlySelectFrom = OptionsElm.getElement(
                        '.quiqqer-locations-recurrenceselect-yearly-day-from'
                    );

                    var MonthYearlySelectFrom = OptionsElm.getElement(
                        '.quiqqer-locations-recurrenceselect-yearly-month-from'
                    );

                    var DayYearlySelectTo = OptionsElm.getElement(
                        '.quiqqer-locations-recurrenceselect-yearly-day-to'
                    );

                    var MonthYearlySelectTo = OptionsElm.getElement(
                        '.quiqqer-locations-recurrenceselect-yearly-month-to'
                    );

                    var fromMonth = MonthYearlySelectFrom.value;
                    var fromDay   = DayYearlySelectFrom.value;

                    if (fromMonth && fromDay) {
                        Options.from = fromMonth + '-' + fromDay;
                    }

                    var toMonth = MonthYearlySelectTo.value;
                    var toDay   = DayYearlySelectTo.value;

                    if (toMonth && toDay) {
                        Options.to = toMonth + '-' + toDay;
                    }
                    break;

                case 'specialday':
                    var DayNumSelect = OptionsElm.getElement(
                        '.quiqqer-locations-recurrenceselect-daynum'
                    );

                    Options.daynum = DayNumSelect.value;

                    var MonthSelect = OptionsElm.getElement(
                        '.quiqqer-locations-recurrenceselect-month'
                    );

                    Options.month = MonthSelect.value;

                    break;
            }

            Data.options = Options;

            return Data;
        },

        /**
         * Set value to control
         *
         * @param {Object} Data
         */
        setValue: function (Data) {
            if (this.$TypeSelect.value !== Data.type) {
                this.$TypeSelect.value = Data.type;
                this.$setOptions();
            }

            var OptionsElm = this.$Elm.getElement(
                '.quiqqer-locations-recurrenceselect-options'
            );

            var Options = Data.options;

            switch (Data.type) {
                case 'daterange':
                    this.$DateInputFrom.setDate(Options.from);
                    this.$DateInputTo.setDate(Options.to);
                    break;

                case 'yearly':
                    var DayYearlySelectFrom = OptionsElm.getElement(
                        '.quiqqer-locations-recurrenceselect-yearly-day-from'
                    );

                    var MonthYearlySelectFrom = OptionsElm.getElement(
                        '.quiqqer-locations-recurrenceselect-yearly-month-from'
                    );

                    var DayYearlySelectTo = OptionsElm.getElement(
                        '.quiqqer-locations-recurrenceselect-yearly-day-to'
                    );

                    var MonthYearlySelectTo = OptionsElm.getElement(
                        '.quiqqer-locations-recurrenceselect-yearly-month-to'
                    );

                    if (!Options.from) {
                        MonthYearlySelectFrom.value = 1;
                        DayYearlySelectFrom.value   = 1;
                    } else {
                        var fromParts = Options.from.split('-');

                        MonthYearlySelectFrom.value = fromParts[0];
                        DayYearlySelectFrom.value   = fromParts[1];
                    }

                    if (!Options.to) {
                        MonthYearlySelectTo.value = 1;
                        DayYearlySelectTo.value   = 1;
                    } else {
                        var toParts = Options.to.split('-');

                        MonthYearlySelectTo.value = toParts[0];
                        DayYearlySelectTo.value   = toParts[1];
                    }
                    break;

                case 'specialday':
                    var DayNumSelect = OptionsElm.getElement(
                        '.quiqqer-locations-recurrenceselect-daynum'
                    );

                    DayNumSelect.value = Options.daynum;

                    var MonthSelect = OptionsElm.getElement(
                        '.quiqqer-locations-recurrenceselect-month'
                    );

                    MonthSelect.value = Options.month;
                    break;
            }
        }
    });
});
