/**
 * Control setting (regular) opening hours for a location
 *
 * @module package/quiqqer/locations/bin/controls/attributes/SpecialOpeningHours/SpecialOpeningHours
 * @author www.pcsg.de (Patrick Müller)
 */
define('package/quiqqer/locations/bin/controls/attributes/SpecialOpeningHours/SpecialOpeningHours', [

    'qui/QUI',
    'qui/controls/Control',
    'qui/controls/buttons/Button',

    'Locale',

    'package/quiqqer/locations/bin/controls/attributes/OpeningHours/OpeningHours',
    'package/quiqqer/locations/bin/controls/attributes/SpecialOpeningHours/RecurrenceSelect',

    'css!package/quiqqer/locations/bin/controls/attributes/SpecialOpeningHours/SpecialOpeningHours.css'

], function (QUI, QUIControl, QUIButton, QUILocale, OpeningHours,
             RecurrenceSelect) {
    "use strict";

    var lg = 'quiqqer/locations';

    return new Class({

        Extends: QUIControl,
        Type   : 'package/quiqqer/locations/bin/controls/attributes/SpecialOpeningHours/SpecialOpeningHours',

        Binds: [
            '$onInject',
            '$onImport',
            '$setValue',
            '$onClickClosed',
            '$onClickOpen24'
        ],

        initialize: function (options) {
            this.parent(options);

            this.addEvents({
                onInject: this.$onInject,
                onImport: this.$onImport
            });

            this.$Input       = null;
            this.$days        = ['MO', 'TU', 'WE', 'TH', 'FR', 'SA', 'SU'];
            this.$EntryList   = null;
            this.$initialLoad = true;
        },

        /**
         * create the domnode element
         *
         * @return {HTMLDivElement}
         */
        create: function () {
            var self = this;

            this.$Elm = new Element('div', {
                'class': 'quiqqer-locations-specialopeninghours',
                html   : '<div class="quiqqer-locations-specialopeninghours-list"></div>' +
                '<div class="quiqqer-locations-specialopeninghours-add"></div>'
            });

            new QUIButton({
                textimage: 'fa fa-plus',
                text     : QUILocale.get(lg, 'controls.attributes.specialopeninghours.btn.add.text'),
                alt      : QUILocale.get(lg, 'controls.attributes.specialopeninghours.btn.add.text'),
                title    : QUILocale.get(lg, 'controls.attributes.specialopeninghours.btn.add.text'),
                events   : {
                    onClick: function () {
                        self.$addSpecialOpeningTime(true);
                    }
                }
            }).inject(
                this.$Elm.getElement('.quiqqer-locations-specialopeninghours-add')
            );

            this.$EntryList = this.$Elm.getElement('.quiqqer-locations-specialopeninghours-list');

            return this.$Elm;
        },

        /**
         * Add a special opening time to the list
         *
         * @param {bool} [withDefaultRow] - with empty default row
         * @return {HTMLDivElement}
         */
        $addSpecialOpeningTime: function (withDefaultRow) {
            var self = this;

            var EntryElm = new Element('div', {
                'class': 'quiqqer-locations-specialopeninghours-entry',
                html   : '<div class="quiqqer-locations-specialopeninghours-entry-remove"></div>' +
                '<div class="quiqqer-locations-specialopeninghours-entry-recurrence">' +
                '<p>' + QUILocale.get(lg, 'controls.attributes.specialopeninghours.recurrence.title') + '</p>' +
                '<div class="quiqqer-locations-specialopeninghours-entry-recurrence-options"></div>' +
                '</div>' +
                '<div class="quiqqer-locations-specialopeninghours-entry-time">' +
                '<p>' + QUILocale.get(lg, 'controls.attributes.specialopeninghours.time.title') + '</p>' +
                '</div>'
            });

            // remove
            new Element('span', {
                'class': 'fa fa-close',
                events : {
                    click: function (event) {
                        event.stop();

                        EntryElm.destroy();
                        self.$setValue();
                    }
                }
            }).inject(
                EntryElm.getElement('.quiqqer-locations-specialopeninghours-entry-remove')
            );

            var OpeningHoursControl = new OpeningHours({
                events: {
                    onChange: function () {
                        self.$setValue();
                    }
                }
            }).inject(
                EntryElm.getElement(
                    '.quiqqer-locations-specialopeninghours-entry-time'
                )
            );

            if (withDefaultRow) {
                OpeningHoursControl.$addEntry();
            }

            // recurrence
            new RecurrenceSelect({
                events: {
                    onChange: function () {
                        self.$setValue();
                    }
                }
            }).inject(
                EntryElm.getElement(
                    '.quiqqer-locations-specialopeninghours-entry-recurrence-options'
                )
            );

            EntryElm.inject(this.$EntryList);

            return EntryElm;
        },

        /**
         * Parses all time inputs and sets value
         */
        $setValue: function () {
            if (this.$initialLoad) {
                return;
            }

            var entries = this.$Elm.getElements(
                '.quiqqer-locations-specialopeninghours-entry'
            );

            var data = [];

            for (var i = 0, len = entries.length; i < len; i++) {
                var Entry     = entries[i];
                var EntryData = {};

                var OpeningHoursControl = QUI.Controls.getById(
                    Entry.getElement(
                        '.quiqqer-locations-openinghours'
                    ).getProperty(
                        'data-quiid'
                    )
                );

                EntryData.time = OpeningHoursControl.getValue();

                var RecurrenceControl = QUI.Controls.getById(
                    Entry.getElement(
                        '.quiqqer-locations-recurrenceselect'
                    ).getProperty(
                        'data-quiid'
                    )
                );

                EntryData.recurrence = RecurrenceControl.getValue();

                data.push(EntryData);
            }

            if (this.$Input) {
                this.$Input.value = JSON.encode(data);
            }
        },

        /**
         * Set time entries from object
         *
         * @param {array} entries
         */
        setEntries: function (entries) {
            for (var i = 0, len = entries.length; i < len; i++) {
                var EntryData   = entries[i];
                var NewEntryElm = this.$addSpecialOpeningTime();

                var OpeningHoursControl = QUI.Controls.getById(
                    NewEntryElm.getElements(
                        '.quiqqer-locations-openinghours'
                    ).getProperty(
                        'data-quiid'
                    )
                );

                OpeningHoursControl.setEntries(EntryData.time);

                var RecurrenceControl = QUI.Controls.getById(
                    NewEntryElm.getElements(
                        '.quiqqer-locations-recurrenceselect'
                    ).getProperty(
                        'data-quiid'
                    )
                );

                RecurrenceControl.setValue(EntryData.recurrence);
            }
        },

        /**
         * event: onImport
         */
        $onImport: function () {
            this.$Input      = this.getElm();
            this.$Input.type = 'hidden';

            var Elm = this.create();
            Elm.inject(this.$Input, 'after');

            if (this.$Input.getParent('.field-container')) {
                var Container = new Element('div', {
                    'class': 'field-container-field'
                });

                Container.wraps(Elm);
            }

            if (this.$Input.value !== '') {
                this.setEntries(JSON.decode(this.$Input.value));
            }

            this.$initialLoad = false;
        }
    });
});
