/**
 * Select view box of current map
 *
 * @module package/quiqqer/locations/bin/controls/settings/ViewBox
 * @author www.pcsg.de (Patrick Müller)
 */
define('package/quiqqer/locations/bin/controls/settings/ViewBox', [

    'qui/controls/Control',
    'qui/controls/loader/Loader',
    'qui/controls/buttons/Button',

    'package/quiqqer/geoutils/bin/Geo',
    'package/quiqqer/geoutils/bin/classes/GeoPoint',

    'css!package/quiqqer/locations/bin/controls/settings/ViewBox.css'

], function (QUIControl, QUILoader, QUIButton, Geo, GeoPoint) {
    "use strict";

    return new Class({
        Extends: QUIControl,
        Type   : 'package/quiqqer/locations/bin/controls/settings/ViewBox',

        Binds: [
            '$onImport',
            '$setSettings',
            '$loadMap',
            '$setValue'
        ],

        options: {},

        initialize: function (options) {
            this.parent(options);

            this.$Input        = null;
            this.$CurrentValue = null;
            this.$Map          = null;
            this.$Content      = null;
            this.Loader        = new QUILoader();

            this.addEvents({
                onImport: this.$onImport
            });
        },

        /**
         * Event: onImport
         */
        $onImport: function () {
            this.$Input = this.getElm();
            this.$Input.setStyle('display', 'none');

            this.$Content = new Element('div', {
                'class': 'quiqqer-locator-settings-viewbox',
            }).inject(this.$Input, 'after');

            this.Loader.inject(this.$Content);

            if (this.$Input.value !== '') {
                this.$CurrentValue = JSON.decode(this.$Input.value);
            }

            this.$loadMap();
        },

        /**
         * Set viewbox data to settings
         */
        $setValue: function () {
            var self = this;

            Promise.all([
                this.$Map.getCenter(),
                this.$Map.getZoom()
            ]).then(function (result) {
                self.$Input.value = JSON.encode({
                    lat : result[0].lat(),
                    lng : result[0].lng(),
                    zoom: result[1]
                });
            });
        },

        /**
         * Load map
         *
         * This causes requests to the map provider (e.g. Google)
         */
        $loadMap: function () {
            var self = this;

            this.Loader.show();

            Geo.getMap({}, true).then(function (Map) {
                self.$Map = Map;

                Map.inject(self.$Content);

                Map.addEvents({
                    onLoaded     : function () {
                        if (self.$CurrentValue) {
                            var Center = new GeoPoint({
                                lat: self.$CurrentValue.lat,
                                lng: self.$CurrentValue.lng
                            });

                            var zoom = self.$CurrentValue.zoom;

                            Map.showCoordinates(Center);
                            Map.setZoom(zoom);
                        }

                        self.Loader.hide();
                    },
                    onDragEnd    : self.$setValue,
                    onZoomChanged: self.$setValue
                });
            });
        }
    });
});