/**
 * Control for managing location media folders
 *
 * @module package/quiqqer/locations/bin/controls/utils/DateInput
 * @author www.pcsg.de (Patrick Müller)
 */
define('package/quiqqer/locations/bin/controls/utils/DateInput', [

    'qui/controls/Control',

    'css!package/quiqqer/locations/bin/controls/utils/DateInput.css'

], function (QUIControl) {
    "use strict";

    return new Class({
        Extends: QUIControl,
        Type   : 'package/quiqqer/locations/bin/controls/utils/DateInput',

        Binds: [
            '$onChange'
        ],

        initialize: function (options) {
            this.parent(options);

            this.$Input = null;

            this.addEvents({
                onImport: this.$onImport
            });
        },

        /**
         * Create Control
         *
         * @return {HTMLElement}
         */
        create: function () {
            this.$Elm = new Element('input', {
                'type'       : 'text',
                'class'      : 'quiqqer-locations-utils-dateinput',
                'placeholder': '2016-12-24',
                events       : {
                    change: this.$onChange
                }
            });

            // try catch because IE does not support input of "date" type
            try {
                this.$Elm.type = 'date';
            } catch (Exception) {
            }

            if (this.getAttribute('class')) {
                this.$Elm.addClass(this.getAttribute('class'));
            }

            return this.$Elm;
        },

        /**
         * Event: onImport
         */
        $onImport: function () {
            this.$Input      = this.getElm();
            this.$Input.type = 'hidden';

            this.create().inject(this.$Input, 'after');

            if (this.$Input.value.trim() !== '') {
                this.$Elm.value = this.$Input.value;
            }
        },

        /**
         * Event: onChange
         */
        $onChange: function () {
            var InputDate = new Date(this.$Elm.value);

            if (InputDate.isValid()) {
                if (this.$Elm.value.split('-').length < 3) {
                    this.$Elm.addClass('input-warn');
                    this.$Elm.value = null;
                } else {
                    this.$Elm.removeClass('input-warn');
                }
            } else {
                this.$Elm.addClass('input-warn');
                this.$Elm.value = null;
            }

            this.fireEvent('change', [this]);
        },

        /**
         * Set value
         *
         * @param {null|string} value
         */
        setDate: function (value) {
            this.$Elm.value = value;
        },

        /**
         * Get date value
         */
        getValue: function () {
            return this.$Elm.value;
        }
    });
});