/**
 * Locator handler
 *
 * @module package/quiqqer/locations/bin/frontend/classes/Locator
 * @author www.pcsg.de (Patrick Müller)
 */
define('package/quiqqer/locations/bin/frontend/classes/Locator', [

    'Ajax'

], function (QUIAjax) {
    "use strict";

    var pkg = 'quiqqer/locations';

    return new Class({

        Type: 'package/quiqqer/locations/bin/frontend/classes/Locator',

        /**
         * Search locations for LocatorList
         *
         * @param {Number} lat
         * @param {Number} lng
         * @param {Number} radius
         * @param {Number} page
         * @param {Boolean} [listOnly]
         * @param {Object} [FilterData]
         * @param {Boolean} [locationImage]
         * @returns {Promise}
         */
        getLocationList: function (lat, lng, radius, page, listOnly, FilterData, locationImage) {
            return new Promise(function (resolve, reject) {
                QUIAjax.get('package_quiqqer_locations_ajax_frontend_Locator_getLocatorListResult', resolve, {
                    'package'    : pkg,
                    lat          : lat,
                    lng          : lng,
                    radius       : radius,
                    page         : page,
                    siteId       : QUIQQER_SITE.id,
                    listOnly     : listOnly ? 1 : 0,
                    filters      : FilterData ? JSON.encode(FilterData) : 0,
                    locationImage: locationImage ? locationImage : 0,
                    onError      : reject
                });
            });
        },

        /**
         * Get coordinates (GeoPoint) of a location based on a Geo identifier
         *
         * @param {String} geoIdentifier
         * @returns {Promise}
         */
        getGeoPointByGeoIdentifier: function (geoIdentifier) {
            return new Promise(function (resolve, reject) {
                QUIAjax.get('package_quiqqer_locations_ajax_frontend_Locator_getGeoPointByGeoIdentifier', resolve, {
                    'package'    : pkg,
                    geoIdentifier: geoIdentifier,
                    onError      : reject
                });
            });
        },

        /**
         * Get a list of geo points for all active locations
         *
         * @param {Object} [FilterData]
         * @returns {Promise}
         */
        getAllLocationPoints: function (FilterData) {
            return new Promise(function (resolve, reject) {
                QUIAjax.get('package_quiqqer_locations_ajax_frontend_Locator_getAllLocationPoints', resolve, {
                    'package': pkg,
                    filters  : FilterData ? JSON.encode(FilterData) : 0,
                    project  : JSON.encode(QUIQQER_PROJECT),
                    siteId   : QUIQQER_SITE.id,
                    onError  : reject
                });
            });
        },

        /**
         * Get HTML content for a location that is displayed in the map
         *
         * @param {Number} locationId
         * @return {Promise}
         */
        getMapLocationDetails: function (locationId) {
            return new Promise(function (resolve, reject) {
                QUIAjax.get('package_quiqqer_locations_ajax_frontend_Locator_getMapLocationDetails', resolve, {
                    'package' : pkg,
                    locationId: locationId,
                    siteId    : QUIQQER_SITE.id,
                    onError   : reject
                });
            });
        },

        /**
         * Search locations for LocatorMap
         *
         * @param {Number} lat
         * @param {Number} lng
         * @param {Number} radius
         * @param {Object} [FilterData]
         * @returns {Promise}
         */
        getMapLocationList: function (lat, lng, radius, FilterData) {
            return new Promise(function (resolve, reject) {
                QUIAjax.get('package_quiqqer_locations_ajax_frontend_Locator_getMapLocationList', resolve, {
                    'package': pkg,
                    lat      : lat,
                    lng      : lng,
                    radius   : radius,
                    filters  : FilterData ? JSON.encode(FilterData) : 0,
                    project  : JSON.encode(QUIQQER_PROJECT),
                    siteId   : QUIQQER_SITE.id,
                    onError  : reject
                });
            });
        },

        /**
         * Get data for a location based on browser Geolocation
         *
         * @param {Number} lat
         * @param {Number} lng
         * @return {Promise}
         */
        getUserGeoLocationData: function (lat, lng) {
            return new Promise(function (resolve, reject) {
                QUIAjax.get('package_quiqqer_locations_ajax_frontend_Locator_getUserGeolocationData', resolve, {
                    'package': pkg,
                    lat      : lat,
                    lng      : lng,
                    onError  : reject
                });
            });
        }
    });
});
