/**
 * List all locations of a category
 *
 * @authro www.pcsg.de (Patrick Müller)
 * @module package/quiqqer/locations/bin/frontend/controls/LocationList
 *
 * @event onLoaded [this] - Fires when category data has been loaded
 */
define('package/quiqqer/locations/bin/frontend/controls/LocationList', [

    'qui/QUI',
    'qui/controls/Control',
    'qui/controls/loader/Loader',
    'utils/Controls',

    'Mustache',
    'Ajax',
    'Locale',

    //'text!package/quiqqer/locations/bin/frontend/controls/LocationList.html',
    //'css!controls/desktop/panels/XML.css'

], function (QUI, QUIControl, QUILoader, QUIControlUtils, Mustache, QUIAjax, QUILocale, template) {
    "use strict";

    var lg = 'quiqqer/locations';

    /**
     * @class package/quiqqer/locations/bin/frontend/controls/LocationList
     *
     * @param {number} locationId - ID of LocationList
     * @param {string} [icon] - Panel icon
     */
    return new Class({

        Extends: QUIControl,
        Type   : 'package/quiqqer/locations/bin/frontend/controls/LocationList',

        Binds: [
            '$onImport',
            '$onPaginationChange'
        ],

        options: {
            categoryid: false,
            listhash  : false,
            sort      : false
        },

        initialize: function (options) {
            this.parent(options);

            this.$Pagination = null;
            this.Loader      = new QUILoader();

            this.addEvents({
                onImport: this.$onImport
            });
        },

        /**
         * Event: onImport
         */
        $onImport: function () {
            var self = this,
                Elm  = this.getElm();

            this.Loader.inject(Elm);
            this.Loader.show();

            // Init pagination
            QUIControlUtils.getControlByElement(
                Elm.getElement('[data-qui="package/quiqqer/controls/bin/navigating/Pagination"]')
            ).then(function (PaginationControl) {
                self.$Pagination = PaginationControl;

                self.$Pagination.addEvents({
                    onChange: self.$onPaginationChange
                });

                self.Loader.hide();
            }, function () {
                // no pagination
                self.Loader.hide();
            });
        },

        /**
         * Event handler for pagination clicks
         *
         * @param {Object} Pagination
         * @param {Object} Sheet
         * @param {Object} Query
         */
        $onPaginationChange: function (Pagination, Sheet, Query) {
            var self = this;

            this.Loader.show();

            QUIAjax.get('package_quiqqer_locations_ajax_frontend_LocationList_get', function (listBodyHtml) {
                var ListBody = self.getElm().getElement('.quiqqer-locations-list');
                ListBody.set('html', listBodyHtml);

                new Fx.Scroll(window).start(0, self.getElm().getPosition().y - 50);

                self.Loader.hide();
            }, {
                'package' : 'quiqqer/locations',
                categoryId: self.getAttribute('categoryid'),
                listHash  : self.getAttribute('listhash'),
                sort      : self.getAttribute('sort'),
                page      : Query.page,
                limit     : Query.limit
            });
        }
    });
});
