<?php

namespace QUI\Locations\Attributes\Types;

use QUI;
use QUI\Locations\Attributes\AbstractAttribute;
use QUI\Countries\Manager as CountriesManager;
use QUI\Locations\Handler\Locations as LocationsHandler;

/**
 * Class Country
 *
 * Select
 *
 * @package QUI\Locations
 */
class Country extends AbstractAttribute
{
    /**
     * Validate the value of an attribute
     *
     * @param string|array $value - The input value (from the frontend)
     * @return bool - true, if value is valid; otherwise an exception is thrown
     *
     * @throws QUI\Locations\Exception
     */
    public function validate($value)
    {
        if (empty($value)) {
            return true;
        }

        if (!CountriesManager::existsCountryCode($value)) {
            throw new QUI\Locations\Exception(array(
                'quiqqer/locations',
                'exception.attributes.types.country.does.not.exist'
            ));
        }

        return true;
    }

    /**
     * Get the value that is used in the search cache table for this attribute
     *
     * @param QUI\Locale $Locale (optional) - Value depending on specific Locale (language);
     * if omitted QUI\Locations\Handler\Locations::getLocale is used
     * @return string - Database value
     */
    public function getSearchCacheValue($Locale = null)
    {
        if (empty($this->value)) {
            return null;
        }

        return CountriesManager::get($this->value)->getName(LocationsHandler::getLocale());
    }

    /**
     * Get the value that is used in the search cache table for this attribute
     *
     * @param QUI\Locale $Locale (optional) - Value depending on specific Locale (language);
     * if omitted QUI\Locations\Handler\Locations::getLocale is used
     * @return string - Database value
     */
    public function getViewValue($Locale = null)
    {
        if (empty($this->value)) {
            return '';
        }

        return CountriesManager::get($this->value)->getName(LocationsHandler::getLocale());
    }
}
