<?php

namespace QUI\Locations\Attributes\Types;

use QUI;
use QUI\Locations\Attributes\AbstractAttribute;
use QUI\Projects\Media\Utils as MediaUtils;
use QUI\Locations\Location\Location;

/**
 * Class MediaFolder
 *
 * Attribute that contains a media folder ID
 *
 * @package QUI\Locations
 */
class MediaFolder extends AbstractAttribute
{
    /**
     * Special set value for this attribute
     *
     * @param mixed $value
     */
    public function setValue($value)
    {
        try {
            parent::setValue($value);
        } catch (\Exception $Exception) {
            QUI\System\Log::writeException($Exception);
            $this->value = null;
            return;
        }

        $this->value = str_replace('&amp;', '&', $this->value);
    }

//    /**
//     * Checks if the media folder exists
//     *
//     * @return bool
//     */
//    protected function existsMediaFolder()
//    {
//        try {
//            MediaUtils::getMediaItemByUrl($this->value);
//        } catch (\Exception $Exception) {
//            return false;
//        }
//
//        return true;
//    }

    /**
     * Validate the value of an attribute
     *
     * @param string|array $value - The input value (from the frontend)
     * @return bool - true, if value is valid; otherwise an exception is thrown
     *
     * @throws QUI\Locations\Exception
     */
    public function validate($value)
    {
        if (empty($value)) {
            return true;
        }

        if (!is_string($value)) {
            throw new QUI\Locations\Exception([
                'quiqqer/locations',
                'exception.attributes.types.datatype.string.expected'
            ]);
        }

        try {
            $Item = MediaUtils::getMediaItemByUrl($value);

            if (!MediaUtils::isFolder($Item)) {
                throw new QUI\Locations\Exception();
            }
        } catch (\Exception $Exception) {
            throw new QUI\Locations\Exception([
                'quiqqer/locations',
                'exception.attributes.types.mediafolder.invalid.url'
            ]);
        }

        return true;
    }

    /**
     * Get the value that is used in the search cache table for this attribute
     *
     * @param QUI\Locale $Locale (optional) - Value depending on specific Locale (language);
     * if omitted QUI\Locations\Handler\Locations::getLocale is used
     * @return string - Database value
     */
    public function getSearchCacheValue($Locale = null)
    {
        // has no search cache value
        return null;
    }

    /**
     * Get the value that is used in the search cache table for this attribute
     *
     * @param QUI\Locale $Locale (optional) - Value depending on specific Locale (language);
     * if omitted QUI\Locations\Handler\Locations::getLocale is used
     * @return string - Database value
     */
    public function getViewValue($Locale = null)
    {
        // has no view value
        return '';
    }

    /**
     * Event: onLocationDelete
     *
     * @param Location $Location - The location that is to be deleted
     */
    public function onLocationDelete($Location)
    {
        // delete location images md
        $ImageFolderAttribute = $Location->getLocationAttribute('imagesMediaFolder');

        $folderUrl = $ImageFolderAttribute->getValue();

        if (!empty($folderUrl)) {
            $Folder = MediaUtils::getMediaItemByUrl($folderUrl);
            $Folder->deactivate();
            $Folder->delete();
            $Folder->destroy();
        }
    }
}
