<?php

namespace QUI\Locations\Controls;

use QUI;
use QUI\Projects\Site\Utils;
use QUI\LocationCategories\Handler as CategoryHandler;
use QUI\Locations\Handler\Locations;
use function GuzzleHttp\Promise\queue;

/**
 * Class LocationView
 *
 * Displays data of one location
 */
class LocationView extends QUI\Control
{
    /**
     * constructor
     *
     * @param array $attributes
     */
    public function __construct($attributes = [])
    {
        // default options
        $this->setAttributes([
            'class'    => 'quiqqer-locationview',
            'Location' => false
        ]);

        parent::__construct($attributes);
    }

    /**
     * Return the inner body of the element
     * Can be overwritten
     *
     * @return String
     */
    public function getBody()
    {
        try {
            $Engine = QUI::getTemplateManager()->getEngine();
        } catch (QUI\Exception $Exception) {
            QUI\System\Log::writeException($Exception);
            return '';
        }

        $Location = $this->getAttribute('Location');

        if (!($Location instanceof QUI\Locations\Location\Location)) {
            return '';
        }

        $locationData        = $Location->getView()->toArray();
        $FrontendLocationMap = false;

        if (!empty($locationData['coordinates'])) {
            $FrontendLocationMap = new QUI\Geo\Utils\Controls\FrontendLocationMap([
                'lat'        => !empty($locationData['coordinates']['lat']) ? $locationData['coordinates']['lat'] : false,
                'lng'        => !empty($locationData['coordinates']['lng']) ? $locationData['coordinates']['lng'] : false,
                'markerIcon' => !empty($locationData['mapIcon']) ? $locationData['mapIcon'] : false
            ]);
        }

        $Slider = null;

        try {
            $folderId = $Location->getLocationAttribute('imagesMediaFolder')->getValue();

            $Slider = new QUI\Gallery\Controls\Slider([
                'folderId' => $folderId,
                'order'    => 'priority ASC'
            ]);
        } catch (QUI\Exception $Exception) {
            QUI\System\Log::writeException($Exception);
        }

        $Engine->assign([
            'location'            => $locationData,
            'FrontendLocationMap' => $FrontendLocationMap,
            'ImageSlider'         => $Slider
        ]);

        // Load default template and CSS
        $css      = \dirname(__FILE__).'/LocationView.css';
        $template = \dirname(__FILE__).'/LocationView.html';

        $this->addCSSFile($css);

        return $Engine->fetch($template);
    }
}
